package com.ruoyi.tuya.service.impl;

import java.util.List;

import com.ruoyi.tuya.domain.BusSupplierRelease;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tuya.mapper.BusSupplierRouteMapper;
import com.ruoyi.tuya.domain.BusSupplierRoute;
import com.ruoyi.tuya.service.IBusSupplierRouteService;

/**
 * 供应商路线Service业务层处理
 *
 * @author zf
 * @date 2022-08-23
 */
@Service
public class BusSupplierRouteServiceImpl implements IBusSupplierRouteService
{
    @Autowired
    private BusSupplierRouteMapper busSupplierRouteMapper;

    /**
     * 查询供应商路线
     *
     * @param id 供应商路线主键
     * @return 供应商路线
     */
    @Override
    public BusSupplierRoute selectBusSupplierRouteById(Long id)
    {
        return busSupplierRouteMapper.selectBusSupplierRouteById(id);
    }

    /**
     * 查询供应商路线列表
     *
     * @param busSupplierRoute 供应商路线
     * @return 供应商路线
     */
    @Override
    public List<BusSupplierRoute> selectBusSupplierRouteList(BusSupplierRoute busSupplierRoute)
    {
        return busSupplierRouteMapper.selectBusSupplierRouteList(busSupplierRoute);
    }

    /**
     * 新增供应商路线
     *
     * @param busSupplierRoute 供应商路线
     * @return 结果
     */
    @Override
    public int insertBusSupplierRoute(BusSupplierRoute busSupplierRoute)
    {
        return busSupplierRouteMapper.insertBusSupplierRoute(busSupplierRoute);
    }

    /**
     * 修改供应商路线
     *
     * @param busSupplierRoute 供应商路线
     * @return 结果
     */
    @Override
    public int updateBusSupplierRoute(BusSupplierRoute busSupplierRoute)
    {
        return busSupplierRouteMapper.updateBusSupplierRoute(busSupplierRoute);
    }

    /**
     * 批量删除供应商路线
     *
     * @param ids 需要删除的供应商路线主键
     * @return 结果
     */
    @Override
    public int deleteBusSupplierRouteByIds(Long[] ids)
    {
        return busSupplierRouteMapper.deleteBusSupplierRouteByIds(ids);
    }

    /**
     * 删除供应商路线信息
     *
     * @param id 供应商路线主键
     * @return 结果
     */
    @Override
    public int deleteBusSupplierRouteById(Long id)
    {
        return busSupplierRouteMapper.deleteBusSupplierRouteById(id);
    }

    /**
     * 修改热门标识
     *
     * @param busSupplierRoute 用户信息
     * @return 结果
     */
    @Override
    public int updateHotForm(BusSupplierRoute busSupplierRoute)
    {
        return busSupplierRouteMapper.updateHotForm(busSupplierRoute);
    }
}
