package com.ruoyi.tuya.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tuya.domain.BusSupplierRelease;
import com.ruoyi.tuya.domain.BusSupplierRoute;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tuya.service.IBusSupplierRouteService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 供应商路线Controller
 *
 * @author zf
 * @date 2022-08-23
 */
@RestController
@RequestMapping("/tuya/supplierroute")
public class BusSupplierRouteController extends BaseController
{
    @Autowired
    private IBusSupplierRouteService busSupplierRouteService;

    /**
     * 查询供应商路线列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusSupplierRoute busSupplierRoute)
    {
        startPage();
        List<BusSupplierRoute> list = busSupplierRouteService.selectBusSupplierRouteList(busSupplierRoute);
        return getDataTable(list);
    }

    /**
     * 导出供应商路线列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:export')")
    @Log(title = "供应商路线", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusSupplierRoute busSupplierRoute)
    {
        List<BusSupplierRoute> list = busSupplierRouteService.selectBusSupplierRouteList(busSupplierRoute);
        ExcelUtil<BusSupplierRoute> util = new ExcelUtil<BusSupplierRoute>(BusSupplierRoute.class);
        util.exportExcel(response, list, "供应商路线数据");
    }

    /**
     * 获取供应商路线详细信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(busSupplierRouteService.selectBusSupplierRouteById(id));
    }

    /**
     * 新增供应商路线
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:add')")
    @Log(title = "供应商路线", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusSupplierRoute busSupplierRoute)
    {
        return toAjax(busSupplierRouteService.insertBusSupplierRoute(busSupplierRoute));
    }

    /**
     * 修改供应商路线
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:edit')")
    @Log(title = "供应商路线", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusSupplierRoute busSupplierRoute)
    {
        return toAjax(busSupplierRouteService.updateBusSupplierRoute(busSupplierRoute));
    }

    /**
     * 删除供应商路线
     */
    @PreAuthorize("@ss.hasPermi('tuya:supplierroute:remove')")
    @Log(title = "供应商路线", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(busSupplierRouteService.deleteBusSupplierRouteByIds(ids));
    }

    /**
     * 热门修改
     */
    @PreAuthorize("@ss.hasPermi('tuya:release:changeHotForm')")
    @Log(title = "平台报价单", businessType = BusinessType.UPDATE)
    @PutMapping("/changeHotForm")
    public AjaxResult changeHotForm(@RequestBody BusSupplierRoute busSupplierRoute)
    {
        return toAjax(busSupplierRouteService.updateHotForm(busSupplierRoute));
    }
}
